from setuptools import setup

setup(
    name='mission',
    version='0.0.1',
    description='Simple threadpool',
    author='YogaPan',
    author_email='godhand1234567@gmail.com',
    packages=['mission'],
    install_requires=[],
    url='https://github.com/yogapan/mission',
    download_url=''
)



from threading import Thread
from queue import Queue


class Mission:
    def __init__(self, max_thread):
        self.queue = Queue()
        self.max_thread = max_thread

    def __enter__(self):
        for x in range(self.max_thread):
            thread = Thread(target=self._threader)
            thread.daemon = True
            thread.start()
        return self

    def __exit__(self, exception_type, exception_value, traceback):
        self.queue.join()

    def send_task(self, func, *args):
        self.queue.put((func, args))

    def _threader(self):
        while True:
            try:
                func, args = self.queue.get()
                func(*args)
                self.queue.task_done()
            except e:
                pass
